pub struct RustCrateFetch { /* private fields */ }Expand description
Builder for accessing Rust crate source code
Implementations
Sourceimpl RustCrateFetch
impl RustCrateFetch
Sourcepub fn new(name: &str, cwd: impl Into<PathBuf>) -> Self
pub fn new(name: &str, cwd: impl Into<PathBuf>) -> Self
Create a new fetch request for the given crate name
Sourcepub fn version(self, version: &str) -> Self
pub fn version(self, version: &str) -> Self
Specify a version constraint (e.g., “^1.0”, “=1.2.3”)
Sourcepub async fn fetch(self) -> Result<FetchResult>
pub async fn fetch(self) -> Result<FetchResult>
Fetch the crate sources, returning the path to extracted sources